'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.WEBSOCKET_ERROR = exports.WEBSOCKET_MESSAGE_RECEIVED = exports.WEBSOCKET_CLOSED = exports.WEBSOCKET_OPEN = exports.WEBSOCKET_CONNECTING = exports.WEBSOCKET_SEND_MESSAGE = exports.WEBSOCKET_DISCONNECT = exports.WEBSOCKET_CONNECT = exports.sendObject = exports.sendMessage = exports.wsDisconnect = exports.wsConnect = exports.createPersistentWebSocketMiddleware = undefined;

var _action = require('./action');

var _utils = require('./utils');

var createPersistentWebSocketMiddleware = exports.createPersistentWebSocketMiddleware = function createPersistentWebSocketMiddleware() {
  var options = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

  var websocketOptions = Object.assign({}, _utils.defaultProps, options);
  var webSocketList = [];
  var webSocketTimeoutList = {};
  var closedByUser = [];

  return function (_ref) {
    var dispatch = _ref.dispatch;
    return function (next) {
      return function (action) {
        switch (action.type) {
          case _action.WEBSOCKET_CONNECT:
            {
              var actionCast = action;

              var activeSocket = (0, _utils.getSocket)(webSocketList, actionCast.url);
              if (!activeSocket) {
                var ws = new WebSocket(actionCast.url);
                (0, _utils.addSocket)(webSocketList, ws);

                ws.onmessage = function (event) {
                  dispatch((0, _action.messageReceived)(event, ws));
                };
                ws.onopen = function () {
                  dispatch((0, _action.open)(ws));
                };
                ws.onclose = function (event) {
                  dispatch((0, _action.closed)(event, ws));
                };
                ws.onerror = function () {
                  dispatch((0, _action.error)('Error in websocket', ws.url));
                };
                next(action);
                next((0, _action.connecting)(ws));
                return;
              }

              break;
            }
          case _action.WEBSOCKET_DISCONNECT:
            {
              var _actionCast = action;

              var socket = (0, _utils.getSocket)(webSocketList, _actionCast.url);
              if (socket) {
                (0, _utils.addSocketToCloseByUser)(closedByUser, socket.url);
                socket.close();
              } else {
                dispatch((0, _action.error)(new Error('Cannot find webSocket'), _actionCast.url || ''));
              }
              break;
            }
          case _action.WEBSOCKET_SEND_MESSAGE:
            {
              var _actionCast2 = action;

              var activeSocketIndex = (0, _utils.getSocketIndex)(webSocketList, _actionCast2.url || '');
              if (activeSocketIndex === -1) {
                dispatch((0, _action.error)(new Error('Cannot find webSocket'), _actionCast2.url || ''));
                break;
              }

              var _activeSocket = webSocketList[activeSocketIndex];

              if (_activeSocket.readyState !== _utils.WS_READY_STATE_OPEN) {
                dispatch((0, _action.error)(new Error('WebSocket is not open'), _activeSocket.url));
                break;
              }

              _activeSocket.send(_actionCast2.message);

              if (websocketOptions.heartbeat) {
                webSocketTimeoutList = (0, _utils.startHeartbeat)(webSocketTimeoutList, _activeSocket, websocketOptions.heartbeatMessage, websocketOptions.heartbeatInterval);
              }
              break;
            }
          case _action.WEBSOCKET_CONNECTING:
            {
              break;
            }
          case _action.WEBSOCKET_OPEN:
            {
              var _actionCast3 = action;

              var _activeSocket2 = (0, _utils.getSocket)(webSocketList, _actionCast3.websocket.url);

              if (!_activeSocket2) {
                dispatch((0, _action.error)(new Error('Error in open WebSocket'), _actionCast3.websocket.url));
                break;
              }

              if (websocketOptions.heartbeat) {
                webSocketTimeoutList = (0, _utils.startHeartbeat)(webSocketTimeoutList, _activeSocket2, websocketOptions.heartbeatMessage, websocketOptions.heartbeatInterval);
              }

              break;
            }
          case _action.WEBSOCKET_CLOSED:
            {
              var _actionCast4 = action;
              if (!_actionCast4.websocket) {
                dispatch((0, _action.error)(new Error('Cannot find webSocket'), _actionCast4.websocket.url));
                break;
              }

              if (websocketOptions.heartbeat) {
                webSocketTimeoutList = (0, _utils.stopHeartbeat)(webSocketTimeoutList, _actionCast4.websocket);
              }

              webSocketList = (0, _utils.removeSocket)(webSocketList, _actionCast4.websocket.url);

              if (!(0, _utils.checkCloseByUser)(closedByUser, _actionCast4.websocket.url) && options.autoReconnect) {
                next(action);
                setTimeout(function () {
                  dispatch((0, _action.wsConnect)(_actionCast4.websocket.url));
                }, options.intervalReconnect);
                return;
              }
              (0, _utils.removeSocketToCloseByUser)(closedByUser, _actionCast4.websocket.url);
              break;
            }
          case _action.WEBSOCKET_MESSAGE_RECEIVED:
            {
              var _actionCast5 = action;

              if (websocketOptions.heartbeat) {
                var _ws = (0, _utils.getSocket)(webSocketList, _actionCast5.websocket.url);

                if (_ws) {
                  webSocketTimeoutList = (0, _utils.startHeartbeat)(webSocketTimeoutList, _ws, websocketOptions.heartbeatMessage, websocketOptions.heartbeatInterval);
                }
              }
              if (options.useMessageAsReduxAction) {
                var obj = '';
                try {
                  obj = JSON.parse(_actionCast5.message);
                } catch (e) {
                  dispatch((0, _action.error)(new Error('Error while parsing Redux Action'), _actionCast5.websocket.url));
                }
                next(action);
                dispatch(obj);
                return;
              }
              break;
            }
          case _action.WEBSOCKET_ERROR:
            {
              break;
            }
          default:
            {
              break;
            }
        }
        next(action);
      };
    };
  };
};

exports.wsConnect = _action.wsConnect;
exports.wsDisconnect = _action.wsDisconnect;
exports.sendMessage = _action.sendMessage;
exports.sendObject = _action.sendObject;
exports.WEBSOCKET_CONNECT = _action.WEBSOCKET_CONNECT;
exports.WEBSOCKET_DISCONNECT = _action.WEBSOCKET_DISCONNECT;
exports.WEBSOCKET_SEND_MESSAGE = _action.WEBSOCKET_SEND_MESSAGE;
exports.WEBSOCKET_CONNECTING = _action.WEBSOCKET_CONNECTING;
exports.WEBSOCKET_OPEN = _action.WEBSOCKET_OPEN;
exports.WEBSOCKET_CLOSED = _action.WEBSOCKET_CLOSED;
exports.WEBSOCKET_MESSAGE_RECEIVED = _action.WEBSOCKET_MESSAGE_RECEIVED;
exports.WEBSOCKET_ERROR = _action.WEBSOCKET_ERROR;