'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.error = exports.messageReceived = exports.closed = exports.open = exports.connecting = exports.sendObject = exports.sendMessage = exports.wsDisconnect = exports.wsConnect = exports.WEBSOCKET_ERROR = exports.WEBSOCKET_MESSAGE_RECEIVED = exports.WEBSOCKET_CLOSED = exports.WEBSOCKET_OPEN = exports.WEBSOCKET_CONNECTING = exports.WEBSOCKET_SEND_MESSAGE = exports.WEBSOCKET_DISCONNECT = exports.WEBSOCKET_CONNECT = undefined;

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _utils = require('./utils');

var WEBSOCKET_CONNECT = exports.WEBSOCKET_CONNECT = 'WEBSOCKET:CONNECT';
var WEBSOCKET_DISCONNECT = exports.WEBSOCKET_DISCONNECT = 'WEBSOCKET:DISCONNECT';
var WEBSOCKET_SEND_MESSAGE = exports.WEBSOCKET_SEND_MESSAGE = 'WEBSOCKET:SEND_MESSAGE';

var WEBSOCKET_CONNECTING = exports.WEBSOCKET_CONNECTING = 'WEBSOCKET:CONNECTING';
var WEBSOCKET_OPEN = exports.WEBSOCKET_OPEN = 'WEBSOCKET:OPEN';
var WEBSOCKET_CLOSED = exports.WEBSOCKET_CLOSED = 'WEBSOCKET:CLOSED';
var WEBSOCKET_MESSAGE_RECEIVED = exports.WEBSOCKET_MESSAGE_RECEIVED = 'WEBSOCKET:MESSAGE_RECEIVED';

var WEBSOCKET_ERROR = exports.WEBSOCKET_ERROR = 'WEBSOCKET:ERROR';

var wsConnect = exports.wsConnect = function wsConnect(url) {
  return {
    type: WEBSOCKET_CONNECT,
    url: url
  };
};

var wsDisconnect = exports.wsDisconnect = function wsDisconnect(url) {
  return _extends({
    type: WEBSOCKET_DISCONNECT
  }, url ? { url: url } : {});
};

var sendMessage = exports.sendMessage = function sendMessage(message, url) {
  return _extends({
    type: WEBSOCKET_SEND_MESSAGE,
    message: message
  }, url ? { url: url } : {});
};

var sendObject = exports.sendObject = function sendObject(object, url) {
  return _extends({
    type: WEBSOCKET_SEND_MESSAGE,
    message: JSON.stringify(object)
  }, url ? { url: url } : {});
};

var connecting = exports.connecting = function connecting(websocket) {
  return {
    type: WEBSOCKET_CONNECTING,
    timeStamp: new Date(),
    websocket: websocket
  };
};

var open = exports.open = function open(websocket) {
  return {
    type: WEBSOCKET_OPEN,
    timeStamp: new Date(),
    websocket: websocket
  };
};

var closed = exports.closed = function closed(event, websocket) {
  return {
    type: WEBSOCKET_CLOSED,
    timeStamp: new Date(),
    event: event,
    reason: (0, _utils.getCloseReasonDescription)(event),
    websocket: websocket
  };
};

var messageReceived = exports.messageReceived = function messageReceived(event, websocket) {
  return {
    type: WEBSOCKET_MESSAGE_RECEIVED,
    timeStamp: new Date(),
    message: typeof event.data === 'string' ? event.data : 'Not string message',
    websocket: websocket
  };
};

var error = exports.error = function error(event, url) {
  return {
    type: WEBSOCKET_ERROR,
    timeStamp: new Date(),
    message: typeof event === 'string' ? event : event.message,
    url: url
  };
};